==> webpdf-wsclient-1.0.1-sources.jar: net/webpdf/wsclient/schema/operation/OcrType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for OcrType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OcrType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="page" type="{http://schema.webpdf.de/1.0/operation}OcrPageType" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="language" type="{http://schema.webpdf.de/1.0/operation}OcrLanguageType" default="eng" /&gt;
 *       &lt;attribute name="outputFormat" default="pdf"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://schema.webpdf.de/1.0/operation}OcrOutputType"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="checkResolution" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="imageDpi" default="200"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://schema.webpdf.de/1.0/operation}DpiType"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="forceEachPage" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OcrType", propOrder = {

})
public class OcrType {

    protected OcrPageType page;
    @XmlAttribute(name = "language")
    protected OcrLanguageType language;
    @XmlAttribute(name = "outputFormat")
    protected OcrOutputType outputFormat;
    @XmlAttribute(name = "checkResolution")
    protected Boolean checkResolution;
    @XmlAttribute(name = "imageDpi")
    protected Integer imageDpi;
    @XmlAttribute(name = "forceEachPage")
    protected Boolean forceEachPage;

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link OcrPageType }
     *     
     */
    public OcrPageType getPage() {
        return page;
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link OcrPageType }
     *     
     */
    public void setPage(OcrPageType value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    /**
     * Gets the value of the language property.
     * 
     * @return
     *     possible object is
     *     {@link OcrLanguageType }
     *     
     */
    public OcrLanguageType getLanguage() {
        if (language == null) {
            return OcrLanguageType.ENG;
        } else {
            return language;
        }
    }

    /**
     * Sets the value of the language property.
     * 
     * @param value
     *     allowed object is
     *     {@link OcrLanguageType }
     *     
     */
    public void setLanguage(OcrLanguageType value) {
        this.language = value;
    }

    public boolean isSetLanguage() {
        return (this.language!= null);
    }

    /**
     * Gets the value of the outputFormat property.
     * 
     * @return
     *     possible object is
     *     {@link OcrOutputType }
     *     
     */
    public OcrOutputType getOutputFormat() {
        if (outputFormat == null) {
            return OcrOutputType.PDF;
        } else {
            return outputFormat;
        }
    }

    /**
     * Sets the value of the outputFormat property.
     * 
     * @param value
     *     allowed object is
     *     {@link OcrOutputType }
     *     
     */
    public void setOutputFormat(OcrOutputType value) {
        this.outputFormat = value;
    }

    public boolean isSetOutputFormat() {
        return (this.outputFormat!= null);
    }

    /**
     * Gets the value of the checkResolution property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCheckResolution() {
        if (checkResolution == null) {
            return true;
        } else {
            return checkResolution;
        }
    }

    /**
     * Sets the value of the checkResolution property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCheckResolution(boolean value) {
        this.checkResolution = value;
    }

    public boolean isSetCheckResolution() {
        return (this.checkResolution!= null);
    }

    public void unsetCheckResolution() {
        this.checkResolution = null;
    }

    /**
     * Gets the value of the imageDpi property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getImageDpi() {
        if (imageDpi == null) {
            return  200;
        } else {
            return imageDpi;
        }
    }

    /**
     * Sets the value of the imageDpi property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setImageDpi(int value) {
        this.imageDpi = value;
    }

    public boolean isSetImageDpi() {
        return (this.imageDpi!= null);
    }

    public void unsetImageDpi() {
        this.imageDpi = null;
    }

    /**
     * Gets the value of the forceEachPage property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isForceEachPage() {
        if (forceEachPage == null) {
            return false;
        } else {
            return forceEachPage;
        }
    }

    /**
     * Sets the value of the forceEachPage property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setForceEachPage(boolean value) {
        this.forceEachPage = value;
    }

    public boolean isSetForceEachPage() {
        return (this.forceEachPage!= null);
    }

    public void unsetForceEachPage() {
        this.forceEachPage = null;
    }

}

==> webpdf-wsclient-2.0.0-sources.jar: net/webpdf/wsclient/schema/operation/OcrType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import net.webpdf.wsclient.ParameterInterface;


/**
 * <p>Java class for OcrType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="OcrType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;all&gt;
 *         &lt;element name="page" type="{http://schema.webpdf.de/1.0/operation}OcrPageType" minOccurs="0"/&gt;
 *       &lt;/all&gt;
 *       &lt;attribute name="language" type="{http://schema.webpdf.de/1.0/operation}OcrLanguageType" default="eng" /&gt;
 *       &lt;attribute name="outputFormat" default="pdf"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://schema.webpdf.de/1.0/operation}OcrOutputType"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="checkResolution" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="imageDpi" default="200"&gt;
 *         &lt;simpleType&gt;
 *           &lt;restriction base="{http://schema.webpdf.de/1.0/operation}DpiType"&gt;
 *           &lt;/restriction&gt;
 *         &lt;/simpleType&gt;
 *       &lt;/attribute&gt;
 *       &lt;attribute name="forceEachPage" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="normalizePageRotation" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="failOnWarning" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "OcrType", propOrder = {

})
public class OcrType
    implements ParameterInterface
{

    protected OcrPageType page;
    @XmlAttribute(name = "language")
    protected OcrLanguageType language;
    @XmlAttribute(name = "outputFormat")
    protected OcrOutputType outputFormat;
    @XmlAttribute(name = "checkResolution")
    protected Boolean checkResolution;
    @XmlAttribute(name = "imageDpi")
    protected Integer imageDpi;
    @XmlAttribute(name = "forceEachPage")
    protected Boolean forceEachPage;
    @XmlAttribute(name = "normalizePageRotation")
    protected Boolean normalizePageRotation;
    @XmlAttribute(name = "failOnWarning")
    protected Boolean failOnWarning;

    /**
     * Gets the value of the page property.
     * 
     * @return
     *     possible object is
     *     {@link OcrPageType }
     *     
     */
    public OcrPageType getPage() {
        return page;
    }

    /**
     * Sets the value of the page property.
     * 
     * @param value
     *     allowed object is
     *     {@link OcrPageType }
     *     
     */
    public void setPage(OcrPageType value) {
        this.page = value;
    }

    public boolean isSetPage() {
        return (this.page!= null);
    }

    /**
     * Gets the value of the language property.
     * 
     * @return
     *     possible object is
     *     {@link OcrLanguageType }
     *     
     */
    public OcrLanguageType getLanguage() {
        if (language == null) {
            return OcrLanguageType.ENG;
        } else {
            return language;
        }
    }

    /**
     * Sets the value of the language property.
     * 
     * @param value
     *     allowed object is
     *     {@link OcrLanguageType }
     *     
     */
    public void setLanguage(OcrLanguageType value) {
        this.language = value;
    }

    public boolean isSetLanguage() {
        return (this.language!= null);
    }

    /**
     * Gets the value of the outputFormat property.
     * 
     * @return
     *     possible object is
     *     {@link OcrOutputType }
     *     
     */
    public OcrOutputType getOutputFormat() {
        if (outputFormat == null) {
            return OcrOutputType.PDF;
        } else {
            return outputFormat;
        }
    }

    /**
     * Sets the value of the outputFormat property.
     * 
     * @param value
     *     allowed object is
     *     {@link OcrOutputType }
     *     
     */
    public void setOutputFormat(OcrOutputType value) {
        this.outputFormat = value;
    }

    public boolean isSetOutputFormat() {
        return (this.outputFormat!= null);
    }

    /**
     * Gets the value of the checkResolution property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isCheckResolution() {
        if (checkResolution == null) {
            return true;
        } else {
            return checkResolution;
        }
    }

    /**
     * Sets the value of the checkResolution property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setCheckResolution(boolean value) {
        this.checkResolution = value;
    }

    public boolean isSetCheckResolution() {
        return (this.checkResolution!= null);
    }

    public void unsetCheckResolution() {
        this.checkResolution = null;
    }

    /**
     * Gets the value of the imageDpi property.
     * 
     * @return
     *     possible object is
     *     {@link Integer }
     *     
     */
    public int getImageDpi() {
        if (imageDpi == null) {
            return  200;
        } else {
            return imageDpi;
        }
    }

    /**
     * Sets the value of the imageDpi property.
     * 
     * @param value
     *     allowed object is
     *     {@link Integer }
     *     
     */
    public void setImageDpi(int value) {
        this.imageDpi = value;
    }

    public boolean isSetImageDpi() {
        return (this.imageDpi!= null);
    }

    public void unsetImageDpi() {
        this.imageDpi = null;
    }

    /**
     * Gets the value of the forceEachPage property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isForceEachPage() {
        if (forceEachPage == null) {
            return false;
        } else {
            return forceEachPage;
        }
    }

    /**
     * Sets the value of the forceEachPage property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setForceEachPage(boolean value) {
        this.forceEachPage = value;
    }

    public boolean isSetForceEachPage() {
        return (this.forceEachPage!= null);
    }

    public void unsetForceEachPage() {
        this.forceEachPage = null;
    }

    /**
     * Gets the value of the normalizePageRotation property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isNormalizePageRotation() {
        if (normalizePageRotation == null) {
            return false;
        } else {
            return normalizePageRotation;
        }
    }

    /**
     * Sets the value of the normalizePageRotation property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setNormalizePageRotation(boolean value) {
        this.normalizePageRotation = value;
    }

    public boolean isSetNormalizePageRotation() {
        return (this.normalizePageRotation!= null);
    }

    public void unsetNormalizePageRotation() {
        this.normalizePageRotation = null;
    }

    /**
     * Gets the value of the failOnWarning property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isFailOnWarning() {
        if (failOnWarning == null) {
            return false;
        } else {
            return failOnWarning;
        }
    }

    /**
     * Sets the value of the failOnWarning property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFailOnWarning(boolean value) {
        this.failOnWarning = value;
    }

    public boolean isSetFailOnWarning() {
        return (this.failOnWarning!= null);
    }

    public void unsetFailOnWarning() {
        this.failOnWarning = null;
    }

}
